.. Django REST framework JSON:API documentation master file, created by
   sphinx-quickstart on Fri Jul 24 23:31:15 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django REST framework JSON:API
==========================================================

Contents:

.. toctree::
   :maxdepth: 2

   getting-started
   usage
   api
   CONTRIBUTING

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

